geowatch.utils.lightning\_ext.lightning\_cli\_ext module
========================================================

.. automodule:: geowatch.utils.lightning_ext.lightning_cli_ext
   :members:
   :undoc-members:
   :show-inheritance:
